// src/index.ts
import * as React from "react";
import { createModel } from "xstate/lib/model";
import { useMachine } from "@xstate/react";

// src/utils.ts
function isEqual(array1, array2) {
  return JSON.stringify(array1) === JSON.stringify(array2);
}
function takeRight(array, n) {
  if (n < 1)
    return [];
  return array.slice(-1 * n);
}

// src/index.ts
var initialContext = {
  cheatCodeKeys: void 0,
  typedKeys: []
};
var creators = {
  events: {
    keydown: (event) => ({ key: event.key })
  }
};
var cheatCodeModel = createModel(initialContext, creators);
var resetTypedKeys = cheatCodeModel.assign({
  typedKeys: initialContext.typedKeys
});
var record = cheatCodeModel.assign({
  typedKeys: (context, event) => [...context.typedKeys, event.key]
}, "keydown");
var cheatCodeMachine = cheatCodeModel.createMachine({
  id: "cheatCodeMachine",
  initial: "disabled",
  states: {
    disabled: {
      id: "disabled",
      initial: "idle",
      states: {
        idle: {
          always: [
            {
              cond: "cheatCodeEntered",
              actions: [resetTypedKeys],
              target: "#enabled"
            }
          ],
          on: {
            keydown: {
              actions: [record],
              target: "recording"
            }
          }
        },
        recording: {
          always: [
            {
              cond: "cheatCodeEntered",
              actions: [resetTypedKeys],
              target: "#enabled"
            }
          ],
          on: {
            keydown: {
              actions: [record],
              target: "recording"
            }
          },
          after: {
            doneTyping: {
              actions: [resetTypedKeys],
              target: "idle"
            }
          }
        }
      }
    },
    enabled: {
      id: "enabled",
      initial: "idle",
      states: {
        idle: {
          always: [
            {
              cond: "cheatCodeEntered",
              actions: [resetTypedKeys],
              target: "#disabled"
            }
          ],
          on: {
            keydown: {
              actions: [record],
              target: "recording"
            }
          }
        },
        recording: {
          always: [
            {
              cond: "cheatCodeEntered",
              actions: [resetTypedKeys],
              target: "#disabled"
            }
          ],
          on: {
            keydown: {
              actions: [record],
              target: "recording"
            }
          },
          after: {
            doneTyping: {
              actions: [resetTypedKeys],
              target: "idle"
            }
          }
        }
      }
    }
  }
}, {
  delays: {
    doneTyping: 2e3
  },
  guards: {
    cheatCodeEntered: (context) => Array.isArray(context.cheatCodeKeys) && isEqual(takeRight(context.typedKeys, context.cheatCodeKeys.length), context.cheatCodeKeys)
  }
});
function useCheatCode(cheatCodeKeys) {
  const machineOpts = React.useMemo(() => ({
    context: { cheatCodeKeys }
  }), [cheatCodeKeys]);
  const [state, send] = useMachine(cheatCodeMachine, machineOpts);
  React.useEffect(() => {
    const handleKeyboardEvent = (event) => {
      send(cheatCodeModel.events.keydown(event));
    };
    window.addEventListener("keydown", handleKeyboardEvent);
    return () => {
      window.removeEventListener("keydown", handleKeyboardEvent);
    };
  }, [send]);
  return state.matches("enabled");
}
var useSecretCode = useCheatCode;
export {
  useCheatCode,
  useSecretCode
};
//# sourceMappingURL=index.mjs.map